<?php

namespace Drupal\inactive_user_management\Plugin\EmailBuilder;

use Drupal\symfony_mailer\EmailInterface;
use Drupal\symfony_mailer\Processor\EmailBuilderBase;
use Drupal\symfony_mailer\Processor\TokenProcessorTrait;

/**
 * Email Builder plug-in for the inactive_user_management module.
 *
 * @EmailBuilder(
 *   id = "inactive_user_mailer",
 *   sub_types = {
 *     "notification" = @Translation("Inactive user notification"),
 *   },
 *   common_adjusters = {"email_subject", "email_body"},
 * )
 */
class InactiveUserEmailBuilder extends EmailBuilderBase {

  use TokenProcessorTrait;

  /**
   * Saves the parameters for a newly created email.
   *
   * After the second parameter, $emailFactory->sendTypedMail() takes a
   * variadic parameter named $params. The contents of $params are then
   * forwarded to ::createParams() after $email.
   *
   * Thus, if you send five parameters to ::sendTypedMail() or
   * ::newTypedMail(), the last three will be sent to ::createParams().
   *
   * @param \Drupal\symfony_mailer\EmailInterface $email
   *   The email to modify.
   * @param string|null $to
   *   The "to" to which the email is sent.
   * @param string|null $subject
   *   The subject of the email.
   * @param string|null $content
   *   The text content of the email.
   */
  public function createParams(EmailInterface $email, ?string $to = NULL, ?string $subject = NULL, ?string $content = NULL): void {
    if ($to && $subject && $content) {
      // For back-compatibility, allow params to be NULL.
      $email->setParam('to', $to);
      $email->setParam('subject', $subject);
      $body[] = [
        '#type' => 'processed_text',
        '#text' => $content,
      ];
      $email->setParam('content', $body);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function build(EmailInterface $email): void {
    if ($to = $email->getParam('to')) {
      $email->setTo($to);
    }
    if ($subject = $email->getParam('subject')) {
      $email->setSubject($subject);
    }
    if ($content = $email->getParam('content')) {
      $email->setBody($content);
    }
  }

}
